"""speed_dating URL Configuration

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/3.2/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""
from django.conf import settings
from django.conf.urls.i18n import i18n_patterns
from django.conf.urls.static import static
from django.contrib import admin
from django.urls import path
from webapp import views as webapp_views
from accounts import views as accounts_views

urlpatterns = [
    path('admin/', admin.site.urls),
]

urlpatterns += i18n_patterns(
    path('login/', accounts_views.LoginView.as_view(), name="login"),
    path('logout/', accounts_views.LogoutView.as_view(), name="logout"),
    path('create/', accounts_views.RegisterView.as_view(), name="register"),
    path("<int:pk>/", accounts_views.UserDetailView.as_view(), name="profile"),
    path("<int:pk>/edit/", accounts_views.UserChangeView.as_view(), name="edit_profile"),
    path("<int:pk>/change-password/", accounts_views.ChangePasswordView.as_view(), name="change_password"),
    path("", webapp_views.index_view, name="index"),
    path("events/", webapp_views.EventView.as_view(), name="list_events"),
    path("events/create/", webapp_views.EventCreateView.as_view(), name="create_events"),
    path("events/<int:pk>/", webapp_views.EventDetailView.as_view(), name="detail_events"),
    path("events/<int:pk>/add-user/", webapp_views.ParticipateView.as_view(), name="add_user"),
    path("events/<int:pk>/edit/", webapp_views.EventUpdateView.as_view(), name="update_events"),
    path("events/<int:pk>/delete/", webapp_views.EventDeleteView.as_view(), name="delete_events"),
    path("events/<int:pk>/view-all-users", webapp_views.ParticipateListInEventView.as_view(),
         name="list_users_in_event")

)

urlpatterns += static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)
